==> samba-1.6.07.tar.gz: includes.h <==
#include "local.h"
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <time.h>
#ifndef sun386
#include <utime.h>
#endif
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/ioctl.h>
#include <sys/time.h>
#include <netinet/in.h>
#include <netdb.h>
#include <signal.h>
#include <errno.h>
#include <sys/file.h>
#include <sys/stat.h>
#include <sys/param.h>
#include <sys/mount.h>
#include <pwd.h>
#ifdef __STDC__
#include <stdarg.h>
#else
#include <varargs.h>
#endif
#include <unistd.h>
#include <sys/wait.h>
#ifdef ISC
#include <sys/stream.h>
#endif
#include <net/if.h>

#if defined(SHADOW_PWD) && !defined(NETBSD)
#include <shadow.h>
#endif

#ifdef LINUX
#include <arpa/inet.h>
#include <dirent.h>
#include <string.h>
#include <sys/vfs.h>
#define SIGNAL_CAST (__sighandler_t)
#define HAVE_TIMEZONE
#define HAVE_SYSCONF 1
#define HAVE_FCNTL_LOCK 1
#endif

#ifdef SUN
#define HAVE_TIMELOCAL
#include <sys/dirent.h>
#include <sys/acct.h>
#include <sys/vfs.h>
#include <string.h>
#include <errno.h>
#ifndef sun386
#include <utime.h>
#endif
#include <sys/wait.h>
#include <signal.h>
#ifdef sun386
/* Things we need to change for sun386i */
#ifdef PWDAUTH
#undef PWDAUTH
#endif
#define strerror strerror
struct utimbuf {
  time_t actime;
  time_t modtime;
};
typedef unsigned short mode_t;
#endif
#ifndef strerror
extern char *sys_errlist[];
#define strerror(i) sys_errlist[i]
#endif
#endif

#ifdef SOLARIS
#include <sys/fcntl.h>
#include <dirent.h>
#include <sys/acct.h>
#include <sys/statfs.h>
#include <sys/vfs.h>
#include <sys/filio.h>
#include <string.h>
#define HAVE_TIMEZONE
#define SIGNAL_CAST (void (*)(int))
#define SYSV
#define REPLACE_STRLEN
#define USE_STATVFS
#endif

#ifdef SVR4
#include <string.h>
#include <sys/dir.h>
#include <dirent.h>
#include <sys/statfs.h>
#include <sys/statvfs.h>
#include <sys/vfs.h>
#include <sys/filio.h>
#include <fcntl.h>
#include <sys/sockio.h>
#include <termios.h>
#define SYSV
#define HAVE_TIMEZONE
#define SIGNAL_CAST (void (*)(int))
#define USE_STATVFS
#endif

#ifdef ULTRIX
#include <strings.h>
#include <nfs/nfs_clnt.h>
#include <nfs/vfs.h>
char *getwd(char *);
#define NOSTRDUP
#endif

#ifdef OSF1
#include <strings.h>
#include <dirent.h>
char *getwd(char *);
#endif

#ifdef BSDI

#endif

#ifdef NETBSD
#include <strings.h>

struct spwd { /* fake shadow password structure */
       char *sp_pwdp;
};
struct spwd *getspnam(char *username); /* fake shadow password routine */
#endif 


#ifdef FreeBSD
#include <strings.h>
#endif 


#ifdef AIX
#include <strings.h>
#include <sys/dir.h>
#include <sys/select.h>
#include <dirent.h>
#include <sys/statfs.h>
#include <sys/vfs.h>
#define HAVE_TIMEZONE
#endif

#ifdef HPUX
#include <string.h>
#include <dirent.h>
#include <fcntl.h>
#include <sys/vfs.h>
#include <sys/types.h>
#define SIGNAL_CAST (void (*)(__harg))
#define SELECT_CAST (int *)
#define HAVE_TIMEZONE
#endif

#ifdef SEQUENT
char *strchr();
char *strrchr();
typedef int mode_t;
#define SEEK_SET 0
#endif

#ifdef NEXT
#include <strings.h>
#include <sys/dir.h>
#include <dirent.h>
#include <sys/vfs.h>
#define bzero(b,len) memset(b,0,len)
#include <libc.h>
#define NOSTRDUP
#endif


#ifdef ISC
#include <sys/stream.h>
#include <net/errno.h>
#include <string.h>
#include <sys/dir.h>
#include <dirent.h>
#include <sys/statfs.h>
#include <fcntl.h>
#include <sys/sioctl.h>
#include <termio.h>
#define NORECVFROM
#define FIONREAD FIORDCHK
#define SYSV
#define SIGNAL_CAST (void (*)(int))
#endif


#ifdef USE_DIRECT
#include <sys/dir.h>
#endif

#include "version.h"
#include "smb.h"

#ifdef REPLACE_STRLEN
#define strlen(s) Strlen(s)
#endif

#ifndef HAVE_SYSCONF
#define HAVE_SYSCONF 0
#endif


#ifndef ENOTSOCK
#define ENOTSOCK EINVAL
#endif

#ifndef SIGCLD
#define SIGCLD SIGCHLD
#endif 

#ifndef GETWD_CACHE
#define GETWD_CACHE 0
#endif

#ifndef HAVE_FCNTL_LOCK
#define HAVE_FCNTL_LOCK 1
#endif

/* possibly wrap the malloc calls */
#if WRAP_MALLOC

/* undo the old malloc def if necessary */
#ifdef malloc
#define xx_old_malloc malloc
#undef malloc
#endif

#define malloc(size) malloc_wrapped(size,__FILE__,__LINE__)

/* undo the old realloc def if necessary */
#ifdef realloc
#define xx_old_realloc realloc
#undef realloc
#endif

#define realloc(ptr,size) realloc_wrapped(ptr,size,__FILE__,__LINE__)

/* and the malloc prototypes */
void *malloc_wrapped(int,char *,int);
void *realloc_wrapped(void *,int,char *,int);

#endif

==> samba-1.7.00.tar.gz: includes.h <==
#include "local.h"
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <time.h>
#if (!(defined(sun386) || defined(NEXT2) || defined(NEXT3_0)))
#include <utime.h>
#endif
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/ioctl.h>
#include <sys/time.h>
#include <netinet/in.h>
#include <netdb.h>
#include <signal.h>
#include <errno.h>
#include <sys/file.h>
#include <sys/stat.h>
#include <sys/param.h>
#include <sys/mount.h>
#include <pwd.h>
#ifdef __STDC__
#include <stdarg.h>
#else
#include <varargs.h>
#endif
#ifndef NEXT3_0
#include <unistd.h>
#endif
#include <sys/wait.h>
#ifdef CLIX	/* need rusage structure */
#include <sys/resource.h>
#endif	/* end CLIX */
#ifdef ISC
#include <sys/stream.h>
#endif
#include <net/if.h>

#if defined(SHADOW_PWD) && !defined(NETBSD)
#include <shadow.h>
#endif

#ifdef LINUX
#include <arpa/inet.h>
#include <dirent.h>
#include <string.h>
#include <sys/vfs.h>
#define SIGNAL_CAST (__sighandler_t)
#define HAVE_TIMEZONE
#define HAVE_SYSCONF 1
#define HAVE_FCNTL_LOCK 1
#define USE_GETCWD
#endif

#ifdef SUN
#define HAVE_TIMELOCAL
#include <sys/dirent.h>
#include <sys/acct.h>
#include <sys/vfs.h>
#include <string.h>
#include <errno.h>
#ifndef sun386
#include <utime.h>
#endif
#include <sys/wait.h>
#include <signal.h>
#ifdef sun386
/* Things we need to change for sun386i */
#define NO_STRFTIME
#ifdef PWDAUTH
#undef PWDAUTH
#endif
#define strerror strerror
struct utimbuf {
  time_t actime;
  time_t modtime;
};
typedef unsigned short mode_t;
#endif
#ifndef strerror
extern char *sys_errlist[];
#define strerror(i) sys_errlist[i]
#endif
#endif

#ifdef SOLARIS
#include <sys/fcntl.h>
#include <dirent.h>
#include <sys/acct.h>
#include <sys/statfs.h>
#ifdef SOLARIS2_2
#include <sys/statvfs.h>
#endif
#include <sys/vfs.h>
#include <sys/filio.h>
#include <string.h>
#define HAVE_TIMEZONE
#define SIGNAL_CAST (void (*)(int))
#define SYSV
#define USE_WAITPID
#define REPLACE_STRLEN
#define USE_STATVFS
#define USE_GETCWD
#endif

#ifdef SGI
#include <sys/statfs.h>
#include <string.h>
#include <signal.h>
#define SYSV
#define SIGNAL_CAST (void (*)())
#define STATFS4
#endif

#ifdef DGUX
#include <string.h>
#include <dirent.h>
#include <sys/statfs.h>
#include <sys/statvfs.h>
#include <fcntl.h>
#include <termios.h>
#define SYSV
#define USE_WAITPID
#define HAVE_TIMEZONE
#define SIGNAL_CAST (void (*)(int))
#define USE_STATVFS
#define USE_GETCWD
#endif

#ifdef SVR4
#include <string.h>
#include <sys/dir.h>
#include <dirent.h>
#include <sys/statfs.h>
#include <sys/statvfs.h>
#include <sys/vfs.h>
#include <sys/filio.h>
#include <fcntl.h>
#include <sys/sockio.h>
#include <termios.h>
#define SYSV
#define USE_WAITPID
#define HAVE_TIMEZONE
#define SIGNAL_CAST (void (*)(int))
#define USE_STATVFS
#define USE_GETCWD
#endif

#ifdef ULTRIX
#include <strings.h>
#include <nfs/nfs_clnt.h>
#include <nfs/vfs.h>
char *getwd(char *);
#define NOSTRDUP
#ifdef __STDC__
#define SIGNAL_CAST (void(*)(int))
#endif
#endif

#ifdef OSF1
#include <strings.h>
#include <dirent.h>
char *getwd(char *);
#define STATFS3
#endif

#ifdef CLIX
#include <dirent.h>
#define SIGNAL_CAST	(void (*)())
#include <sys/fcntl.h>
#include <sys/statfs.h>
#define HAVE_TIMEZONE
#include <string.h>
#define NO_EID
#define USE_WAITPID
#define STATFS4
#define NO_FSYNC
#define USE_GETCWD
#define USE_SETSID
#endif	/* CLIX */


#ifdef BSDI
#include <string.h>
#endif

#ifdef NETBSD
#include <strings.h>
/* you may not need this */
#define NO_GETSPNAM
#define SIGNAL_CAST (void (*)())
#endif 


#ifdef FreeBSD
#include <strings.h>
#endif 


#ifdef AIX
#include <strings.h>
#include <sys/dir.h>
#include <sys/select.h>
#include <dirent.h>
#include <sys/statfs.h>
#include <sys/vfs.h>
#define HAVE_TIMEZONE
#define SYSV
#define USE_WAITPID
#endif

#ifdef HPUX
#include <string.h>
#include <dirent.h>
#include <fcntl.h>
#include <sys/vfs.h>
#include <sys/types.h>
#define SIGNAL_CAST (void (*)(__harg))
#define SELECT_CAST (int *)
#define HAVE_TIMEZONE
#define SYSV
#define USE_WAITPID
#define WAIT3_CAST (int *)
#define USE_GETCWD
#define USE_SETSID
#define USE_SETRES
#endif

#ifdef SEQUENT
char *strchr();
char *strrchr();
typedef int mode_t;
#define SEEK_SET 0
#endif

#ifdef NEXT
#include <strings.h>
#include <sys/dir.h>
#include <dirent.h>
#include <sys/vfs.h>
#define bzero(b,len) memset(b,0,len)
#include <libc.h>
#define NOSTRDUP
#define USE_WAITPID
#define NO_STRFTIME
#define USE_GETCWD
#endif

#ifdef NEXT2
#include <sys/types.h>
#include <strings.h>
#include <dirent.h>
#include <sys/vfs.h>
#define bzero(b,len) memset(b,0,len)
#define mode_t int
struct utimbuf {
  time_t actime;
  time_t modtime;
};
#include <libc.h>
#define NOSTRDUP
#define USE_DIRECT
#define USE_WAITPID
#endif 

#ifdef NEXT3_0
#include <strings.h>
#include <sys/dir.h>
#include <sys/vfs.h>
#define bzero(b,len) memset(b,0,len)
struct utimbuf {
  time_t actime;
  time_t modtime;
};
#include <libc.h>
#define NOSTRDUP
#define USE_DIRECT
#define mode_t int
#endif


#ifdef SCO
#include <dirent.h>
#include <string.h>
#include <fcntl.h>
#include <sys/statfs.h>
#include <sys/stropts.h>
#ifdef NETGROUP
#include <rpcsvc/ypclnt.h>
#endif
#ifdef SecureWare
#include <sys/security.h>
#include <sys/audit.h>
#include <prot.h>
#define crypt bigcrypt
#endif
#define HAVE_TIMEZONE
#define SIGNAL_CAST (void (*)(int))
#define USE_WAITPID
#define USE_GETCWD
#define USE_SETSID
#define USE_IFREQ
#define NO_FTRUNCATE
#define STATFS4
#define NO_FSYNC
#endif

#ifdef ISC
#include <net/errno.h>
#include <string.h>
#include <sys/dir.h>
#include <dirent.h>
#include <sys/statfs.h>
#include <fcntl.h>
#include <sys/sioctl.h>
#include <stropts.h>
#include <termio.h>
#define FIONREAD FIORDCHK
#define SYSV
#define USE_WAITPID
#define SIGNAL_CAST (void (*)(int))
#define USE_GETCWD
#define USE_SETSID
#define USE_IFREQ
#define NO_FTRUNCATE
#define STATFS4
#define NO_FSYNC
#endif


#ifdef NO_GETSPNAM
struct spwd { /* fake shadow password structure */
       char *sp_pwdp;
};
struct spwd *getspnam(char *username); /* fake shadow password routine */
#endif

#ifdef USE_DIRECT
#include <sys/dir.h>
#endif

#ifndef MAXPATHLEN
#define MAXPATHLEN 1024
#endif

#include "version.h"
#include "smb.h"

#ifdef REPLACE_STRLEN
#define strlen(s) Strlen(s)
#endif

#ifndef HAVE_SYSCONF
#define HAVE_SYSCONF 0
#endif


/* maybe this unix doesn't separate RD and WR locks? */
#ifndef F_RDLCK
#define F_RDLCK F_WRLCK
#endif

#ifndef ENOTSOCK
#define ENOTSOCK EINVAL
#endif

#ifndef SIGCLD
#define SIGCLD SIGCHLD
#endif 

#ifndef GETWD_CACHE
#define GETWD_CACHE 1
#endif

#ifndef HAVE_FCNTL_LOCK
#define HAVE_FCNTL_LOCK 1
#endif

#ifndef WAIT3_CAST
#define WAIT3_CAST (struct rusage *)
#endif

#ifdef NO_EID
#define geteuid() getuid()
#define getegid() getgid()
#define seteuid(x) setuid(x)
#define setegid(x) setgid(x)
#endif



/* possibly wrap the malloc calls */
#if WRAP_MALLOC

/* undo the old malloc def if necessary */
#ifdef malloc
#define xx_old_malloc malloc
#undef malloc
#endif

#define malloc(size) malloc_wrapped(size,__FILE__,__LINE__)

/* undo the old realloc def if necessary */
#ifdef realloc
#define xx_old_realloc realloc
#undef realloc
#endif

#define realloc(ptr,size) realloc_wrapped(ptr,size,__FILE__,__LINE__)

/* undo the old free def if necessary */
#ifdef free
#define xx_old_free free
#undef free
#endif

#define free(ptr) free_wrapped(ptr,__FILE__,__LINE__)

/* and the malloc prototypes */
void *malloc_wrapped(int,char *,int);
void *realloc_wrapped(void *,int,char *,int);
void free_wrapped(void *,char *,int);

#endif
